==> haskell-memotrie-0.6.11-99.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MemoTrie
version:              0.6.11
visibility:           public
id:                   MemoTrie-0.6.11-EzCPS0AcENCFqJcGrA4JYn
key:                  MemoTrie-0.6.11-EzCPS0AcENCFqJcGrA4JYn
license:              BSD-3-Clause
copyright:            (c) 2008-2019 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
homepage:             https://github.com/conal/MemoTrie
synopsis:             Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.

    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>

    &#199; 2008-2019 by Conal Elliott; BSD3 license.

category:             Data
abi:                  fec15f6c104154fd83542d08ea5b5691
exposed:              True
exposed-modules:      Data.MemoTrie
import-dirs:          /usr/lib/ghc-9.6.6/site-local/MemoTrie-0.6.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/MemoTrie-0.6.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/MemoTrie-0.6.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-memotrie
hs-libraries:         HSMemoTrie-0.6.11-EzCPS0AcENCFqJcGrA4JYn
depends:
    base-4.18.2.1 newtype-generics-0.6.2-L41i2Wy7676A5ZGTFbM2pb

haddock-interfaces:   /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html:         /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-memotrie-0.6.11-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MemoTrie
version:              0.6.11
visibility:           public
id:                   MemoTrie-0.6.11-JBrVOshtmKn292FiNTA9B
key:                  MemoTrie-0.6.11-JBrVOshtmKn292FiNTA9B
license:              BSD-3-Clause
copyright:            (c) 2008-2019 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
homepage:             https://github.com/conal/MemoTrie
synopsis:             Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.

    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>

    &#199; 2008-2019 by Conal Elliott; BSD3 license.

category:             Data
abi:                  7bb66fdb057c4f5631c5f66389a9da04
exposed:              True
exposed-modules:      Data.MemoTrie
import-dirs:          /usr/lib/ghc-9.6.6/site-local/MemoTrie-0.6.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/MemoTrie-0.6.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/MemoTrie-0.6.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-memotrie
hs-libraries:         HSMemoTrie-0.6.11-JBrVOshtmKn292FiNTA9B
depends:
    base-4.18.2.1 newtype-generics-0.6.2-ymH9MwDygyJ951Ym9cZxw

haddock-interfaces:   /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html:         /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
